/*
 *                 Sun Public License Notice
 * 
 * The contents of this file are subject to the Sun Public License
 * Version 1.0 (the "License"). You may not use this file except in
 * compliance with the License. A copy of the License is available at
 * http://www.sun.com/
 * 
 * The Original Code is NetBeans. The Initial Developer of the Original
 * Code is Sun Microsystems, Inc. Portions Copyright 1997-2001 Sun
 * Microsystems, Inc. All Rights Reserved.
 */

package org.netbeans.examples.modules.minicomposer;

import java.awt.datatransfer.DataFlavor;
import java.awt.datatransfer.Transferable;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.IOException;
import java.util.*;

import org.openide.actions.*;
import org.openide.nodes.*;
import org.openide.util.actions.SystemAction;
import org.openide.util.*;
import org.openide.util.datatransfer.ExTransferable;
import org.openide.util.datatransfer.PasteType;

/** Node representing one note in a score.
 */
public class NoteNode extends AbstractNode implements PropertyChangeListener {
    private final Score.Note note;
    private boolean addedCookieListener;
    public NoteNode(Score.Note note) {
        super(Children.LEAF);
        this.note = note;
        setName(Score.TONES_SHORT[note.getTone()] + "/" +
                Score.OCTAVES_SHORT[note.getOctave()] + "/" +
                Score.DURATIONS_SHORT[note.getDuration()]);
        setDisplayName(NbBundle.getMessage(NoteNode.class, "LBL_note_node",
                       Score.TONES_LONG[note.getTone()],
                       Score.OCTAVES_LONG[note.getOctave()],
                       Score.DURATIONS_LONG[note.getDuration()]));
        setIconBase("/org/netbeans/examples/modules/minicomposer/NoteIcon");
    }
    protected SystemAction[] createActions() {
        return new SystemAction[] {
            SystemAction.get(MoveUpAction.class),
            SystemAction.get(MoveDownAction.class),
            null,
            SystemAction.get(CutAction.class),
            SystemAction.get(CopyAction.class),
            SystemAction.get(PasteAction.class),
            null,
            SystemAction.get(DeleteAction.class),
            null,
            SystemAction.get(PropertiesAction.class),
            SystemAction.get(ToolsAction.class),
        };
    }
    public Node.Cookie getCookie(Class c) {
        if (c == Index.class || c == Index.Support.class) {
            return null;
        }
        Node parent = getParentNode();
        if (parent == null) return null;
        if (!addedCookieListener) {
            addedCookieListener = true;
            parent.addPropertyChangeListener(WeakListener.propertyChange(this, parent));
        }
        Node.Cookie cookie = parent.getCookie(c);
        return cookie;
    }
    public void propertyChange(PropertyChangeEvent evt) {
        if (Node.PROP_COOKIE.equals(evt.getPropertyName())) {
            fireCookieChange();
        }
    }
    public HelpCtx getHelpCtx() {
        return new HelpCtx("org.netbeans.examples.modules.minicomposer");
    }
    public boolean canRename() {
        return false;
    }
    public boolean canDestroy() {
        return true;
    }
    public void destroy() throws IOException {
        ScoreCookie cookie = (ScoreCookie)getCookie(ScoreCookie.class);
        if (cookie == null) throw new IOException();
        Score s = cookie.getScore();
        int size = s.getSize();
        List notes = new ArrayList(Math.max(size - 1, 1));
        for (int i = 0; i < size; i++) {
            Score.Note n = s.getNote(i);
            if (n != note) {
                notes.add(n);
            }
        }
        if (notes.size() != size - 1) throw new IOException("did not find note " + note + " among " + notes);
        cookie.setScore(new Score(notes));
    }
    public boolean canCopy() {
        return true;
    }
    public boolean canCut() {
        return true;
    }
    public Transferable clipboardCopy() throws IOException {
        Transferable deflt = super.clipboardCopy();
        ExTransferable multi = ExTransferable.create(deflt);
        multi.put(new ExTransferable.Single(DataFlavor.stringFlavor) {
            protected Object getData() {
                return NoteNode.this.getName() + "\n";
            }
        });
        multi.put(new ExTransferable.Single(NoteTransfer.NOTE_FLAVOR) {
            protected Object getData() {
                return new Score.Note[] {note};
            }
        });
        return multi;
    }
    public Transferable clipboardCut() throws IOException {
        destroy();
        return clipboardCopy();
    }
    protected void createPasteTypes(Transferable t, List s) {
        super.createPasteTypes(t, s);
        PasteType p = NoteTransfer.createNotePasteType(t, (ScoreCookie)getCookie(ScoreCookie.class), note);
        if (p != null) {
            s.add(p);
        }
    }
    protected Sheet createSheet() {
        Sheet s = super.createSheet();
        Sheet.Set ss = Sheet.createPropertiesSet();
        ScoreCookie cookie = (ScoreCookie)getCookie(ScoreCookie.class);
        ss.put(new NoteProperty(cookie, note, 0));
        ss.put(new NoteProperty(cookie, note, 1));
        ss.put(new NoteProperty(cookie, note, 2));
        s.put(ss);
        return s;
    }
}
